==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_entities/positionequipment_001/ManufacturerInfo.java <==

package net.datastream.schemas.mp_entities.positionequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.TYPE_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERIALNUMBER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MODEL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MODELREVISION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HARDWAREVER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOFTWAREVER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PURCHASINGASSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BIOMEDICALASSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UMDNS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OEMSITE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VENDOR" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COVERAGETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}XCOORDINATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}YCOORDINATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ZCOORDINATE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "manufacturercode",
    "serialnumber",
    "model",
    "modelrevision",
    "hardwarever",
    "softwarever",
    "purchasingasset",
    "biomedicalasset",
    "umdns",
    "oemsite",
    "vendor",
    "coveragetype",
    "xcoordinate",
    "ycoordinate",
    "zcoordinate"
})
@XmlRootElement(name = "ManufacturerInfo")
public class ManufacturerInfo {

    @XmlElement(name = "MANUFACTURERCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufacturercode;
    @XmlElement(name = "SERIALNUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String serialnumber;
    @XmlElement(name = "MODEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String model;
    @XmlElement(name = "MODELREVISION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String modelrevision;
    @XmlElement(name = "HARDWAREVER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String hardwarever;
    @XmlElement(name = "SOFTWAREVER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String softwarever;
    @XmlElement(name = "PURCHASINGASSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected String purchasingasset;
    @XmlElement(name = "BIOMEDICALASSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected String biomedicalasset;
    @XmlElement(name = "UMDNS", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type umdns;
    @XmlElement(name = "OEMSITE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String oemsite;
    @XmlElement(name = "VENDOR", namespace = "http://schemas.datastream.net/MP_fields")
    protected String vendor;
    @XmlElement(name = "COVERAGETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type coveragetype;
    @XmlElement(name = "XCOORDINATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY xcoordinate;
    @XmlElement(name = "YCOORDINATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY ycoordinate;
    @XmlElement(name = "ZCOORDINATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY zcoordinate;

    /**
     * Obtient la valeur de la propriété manufacturercode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTURERCODE() {
        return manufacturercode;
    }

    /**
     * Définit la valeur de la propriété manufacturercode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTURERCODE(String value) {
        this.manufacturercode = value;
    }

    /**
     * Obtient la valeur de la propriété serialnumber.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSERIALNUMBER() {
        return serialnumber;
    }

    /**
     * Définit la valeur de la propriété serialnumber.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSERIALNUMBER(String value) {
        this.serialnumber = value;
    }

    /**
     * Obtient la valeur de la propriété model.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMODEL() {
        return model;
    }

    /**
     * Définit la valeur de la propriété model.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMODEL(String value) {
        this.model = value;
    }

    /**
     * Obtient la valeur de la propriété modelrevision.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMODELREVISION() {
        return modelrevision;
    }

    /**
     * Définit la valeur de la propriété modelrevision.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMODELREVISION(String value) {
        this.modelrevision = value;
    }

    /**
     * Obtient la valeur de la propriété hardwarever.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHARDWAREVER() {
        return hardwarever;
    }

    /**
     * Définit la valeur de la propriété hardwarever.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHARDWAREVER(String value) {
        this.hardwarever = value;
    }

    /**
     * Obtient la valeur de la propriété softwarever.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSOFTWAREVER() {
        return softwarever;
    }

    /**
     * Définit la valeur de la propriété softwarever.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSOFTWAREVER(String value) {
        this.softwarever = value;
    }

    /**
     * Obtient la valeur de la propriété purchasingasset.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPURCHASINGASSET() {
        return purchasingasset;
    }

    /**
     * Définit la valeur de la propriété purchasingasset.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPURCHASINGASSET(String value) {
        this.purchasingasset = value;
    }

    /**
     * Obtient la valeur de la propriété biomedicalasset.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIOMEDICALASSET() {
        return biomedicalasset;
    }

    /**
     * Définit la valeur de la propriété biomedicalasset.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIOMEDICALASSET(String value) {
        this.biomedicalasset = value;
    }

    /**
     * Obtient la valeur de la propriété umdns.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getUMDNS() {
        return umdns;
    }

    /**
     * Définit la valeur de la propriété umdns.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setUMDNS(TYPE_Type value) {
        this.umdns = value;
    }

    /**
     * Obtient la valeur de la propriété oemsite.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOEMSITE() {
        return oemsite;
    }

    /**
     * Définit la valeur de la propriété oemsite.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOEMSITE(String value) {
        this.oemsite = value;
    }

    /**
     * Obtient la valeur de la propriété vendor.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVENDOR() {
        return vendor;
    }

    /**
     * Définit la valeur de la propriété vendor.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVENDOR(String value) {
        this.vendor = value;
    }

    /**
     * Obtient la valeur de la propriété coveragetype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getCOVERAGETYPE() {
        return coveragetype;
    }

    /**
     * Définit la valeur de la propriété coveragetype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setCOVERAGETYPE(TYPE_Type value) {
        this.coveragetype = value;
    }

    /**
     * Obtient la valeur de la propriété xcoordinate.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getXCOORDINATE() {
        return xcoordinate;
    }

    /**
     * Définit la valeur de la propriété xcoordinate.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setXCOORDINATE(QUANTITY value) {
        this.xcoordinate = value;
    }

    /**
     * Obtient la valeur de la propriété ycoordinate.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getYCOORDINATE() {
        return ycoordinate;
    }

    /**
     * Définit la valeur de la propriété ycoordinate.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setYCOORDINATE(QUANTITY value) {
        this.ycoordinate = value;
    }

    /**
     * Obtient la valeur de la propriété zcoordinate.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getZCOORDINATE() {
        return zcoordinate;
    }

    /**
     * Définit la valeur de la propriété zcoordinate.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setZCOORDINATE(QUANTITY value) {
        this.zcoordinate = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/positionequipment_001/ManufacturerInfo.java <==

package net.datastream.schemas.mp_entities.positionequipment_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.TYPE_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERCODE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SERIALNUMBER" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MODEL" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MODELREVISION" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}HARDWAREVER" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SOFTWAREVER" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PURCHASINGASSET" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}BIOMEDICALASSET" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UMDNS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}OEMSITE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}VENDOR" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}COVERAGETYPE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}XCOORDINATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}YCOORDINATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ZCOORDINATE" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "manufacturercode",
    "serialnumber",
    "model",
    "modelrevision",
    "hardwarever",
    "softwarever",
    "purchasingasset",
    "biomedicalasset",
    "umdns",
    "oemsite",
    "vendor",
    "coveragetype",
    "xcoordinate",
    "ycoordinate",
    "zcoordinate"
})
@XmlRootElement(name = "ManufacturerInfo")
public class ManufacturerInfo {

    @XmlElement(name = "MANUFACTURERCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufacturercode;
    @XmlElement(name = "SERIALNUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String serialnumber;
    @XmlElement(name = "MODEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String model;
    @XmlElement(name = "MODELREVISION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String modelrevision;
    @XmlElement(name = "HARDWAREVER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String hardwarever;
    @XmlElement(name = "SOFTWAREVER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String softwarever;
    @XmlElement(name = "PURCHASINGASSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected String purchasingasset;
    @XmlElement(name = "BIOMEDICALASSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected String biomedicalasset;
    @XmlElement(name = "UMDNS", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type umdns;
    @XmlElement(name = "OEMSITE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String oemsite;
    @XmlElement(name = "VENDOR", namespace = "http://schemas.datastream.net/MP_fields")
    protected String vendor;
    @XmlElement(name = "COVERAGETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type coveragetype;
    @XmlElement(name = "XCOORDINATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY xcoordinate;
    @XmlElement(name = "YCOORDINATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY ycoordinate;
    @XmlElement(name = "ZCOORDINATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY zcoordinate;

    /**
     * Gets the value of the manufacturercode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTURERCODE() {
        return manufacturercode;
    }

    /**
     * Sets the value of the manufacturercode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTURERCODE(String value) {
        this.manufacturercode = value;
    }

    /**
     * Gets the value of the serialnumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSERIALNUMBER() {
        return serialnumber;
    }

    /**
     * Sets the value of the serialnumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSERIALNUMBER(String value) {
        this.serialnumber = value;
    }

    /**
     * Gets the value of the model property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMODEL() {
        return model;
    }

    /**
     * Sets the value of the model property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMODEL(String value) {
        this.model = value;
    }

    /**
     * Gets the value of the modelrevision property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMODELREVISION() {
        return modelrevision;
    }

    /**
     * Sets the value of the modelrevision property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMODELREVISION(String value) {
        this.modelrevision = value;
    }

    /**
     * Gets the value of the hardwarever property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHARDWAREVER() {
        return hardwarever;
    }

    /**
     * Sets the value of the hardwarever property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHARDWAREVER(String value) {
        this.hardwarever = value;
    }

    /**
     * Gets the value of the softwarever property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSOFTWAREVER() {
        return softwarever;
    }

    /**
     * Sets the value of the softwarever property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSOFTWAREVER(String value) {
        this.softwarever = value;
    }

    /**
     * Gets the value of the purchasingasset property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPURCHASINGASSET() {
        return purchasingasset;
    }

    /**
     * Sets the value of the purchasingasset property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPURCHASINGASSET(String value) {
        this.purchasingasset = value;
    }

    /**
     * Gets the value of the biomedicalasset property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIOMEDICALASSET() {
        return biomedicalasset;
    }

    /**
     * Sets the value of the biomedicalasset property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIOMEDICALASSET(String value) {
        this.biomedicalasset = value;
    }

    /**
     * Gets the value of the umdns property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getUMDNS() {
        return umdns;
    }

    /**
     * Sets the value of the umdns property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setUMDNS(TYPE_Type value) {
        this.umdns = value;
    }

    /**
     * Gets the value of the oemsite property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOEMSITE() {
        return oemsite;
    }

    /**
     * Sets the value of the oemsite property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOEMSITE(String value) {
        this.oemsite = value;
    }

    /**
     * Gets the value of the vendor property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVENDOR() {
        return vendor;
    }

    /**
     * Sets the value of the vendor property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVENDOR(String value) {
        this.vendor = value;
    }

    /**
     * Gets the value of the coveragetype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getCOVERAGETYPE() {
        return coveragetype;
    }

    /**
     * Sets the value of the coveragetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setCOVERAGETYPE(TYPE_Type value) {
        this.coveragetype = value;
    }

    /**
     * Gets the value of the xcoordinate property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getXCOORDINATE() {
        return xcoordinate;
    }

    /**
     * Sets the value of the xcoordinate property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setXCOORDINATE(QUANTITY value) {
        this.xcoordinate = value;
    }

    /**
     * Gets the value of the ycoordinate property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getYCOORDINATE() {
        return ycoordinate;
    }

    /**
     * Sets the value of the ycoordinate property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setYCOORDINATE(QUANTITY value) {
        this.ycoordinate = value;
    }

    /**
     * Gets the value of the zcoordinate property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getZCOORDINATE() {
        return zcoordinate;
    }

    /**
     * Sets the value of the zcoordinate property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setZCOORDINATE(QUANTITY value) {
        this.zcoordinate = value;
    }

}
